@@ -7,7 +7,7 @@ from ...core.entities.mod_loaders import ModLoaders
 from ...core.entities.version_info import VersionInfo
 from ...core.utils.latest_version_finder import LatestVersionFinder
 from ...utils.logger import LogColors, Logger
-from ..download.download import Download, DownloadInfo
+from ..download.download import Download
 from .install_repo import InstallRepo
 
 
@@ -66,10 +66,9 @@ class Install(Download):
 
         return loader_max
 
-    def on_version_found(self, download_info: DownloadInfo) -> None:
-        # TODO #32 improve message
+    def on_version_found(self, old: Mod, new: Mod) -> None:
         Logger.info(
-            f"🟢 Installed ({download_info.version_info.filename})",
+            f"🟢 Installed version {new.version}",
             LogColors.green,
             indent=1,
         )
