@@ -113,6 +113,12 @@ class Mod(ModArg):
                 without_fabric = re.sub(r"-fabric\w*|fabric\w*-", "", filename)
                 possible_names.add(without_fabric)
 
+        # Split parts of name
+        split_names: Set[str] = set()
+        for possible_name in possible_names:
+            split_names.update(possible_name.split("-"))
+        possible_names.update(split_names)
+
         return possible_names
 
     def __members(self):
