@@ -81,7 +81,7 @@ def test_get_mod_info(name, file, expected):
     print(name)
     input = path(file)
 
-    result = JarParser.get_mod_info(input)
+    result = JarParser._get_mod_info(input)
 
     assert expected == result
 
